@@ -11,7 +11,7 @@ def print_log(message, level=INFO):
     now = datetime.now()
     pid = os.getpid()
     current_thread = threading.current_thread()
-    thread_id = f'{current_thread.getName()}-{current_thread.native_id}-{current_thread.ident}'
+    thread_info = f'{current_thread.getName()}-{current_thread.native_id}-{current_thread.ident}'
 
     # temporarily empty
     trace_id = ''
@@ -20,5 +20,5 @@ def print_log(message, level=INFO):
     frame = callerframerecord[0]
     info = inspect.getframeinfo(frame)
 
-    log_str = f'{now}|{trace_id}|{pid}|{thread_id}|{level}|{info.filename}-{info.lineno}|{str(message)}'
+    log_str = f'{now}|{trace_id}|{pid}|{thread_info}|{level}|{info.filename}-{info.lineno}|{str(message)}'
     print(log_str)
